FakeBti

Struct FakeBti 

pub struct FakeBti(/* private fields */);
A fake BTI object which can be created without having access to hardware resources.

Implementations

Source

impl FakeBti

pub fn phys_addr() -> usize

All physical addresses returned by zx_bti_pin with a fake BTI will be set to this value.

pub fn create() -> Result<Self, Status>

Creates a new FakeBti.

pub fn set_paddrs(&self, paddrs: &[zx_paddr_t])

Sets the paddrs used by the fake BTI. Whenever zx::Bti::pin is called, these static paddrs will be written out into the resulting array. If more physical addresses are needed than are available in paddrs, pin will return an error.

Methods from Deref<Target = Bti>

pub fn raw_handle(&self) -> u32

Return the handle’s integer value.

pub fn is_invalid(&self) -> bool

pub fn unowned(&self) -> Unowned<'_, Bti>

Returns an [Unowned] referring to this handle.

pub fn as_handle_ref(&self) -> Unowned<'_, NullableHandle>

Returns a HandleRef referring to this handle.

pub fn duplicate(&self, rights: Rights) -> Result<Bti, Status>

Wraps the zx_handle_duplicate syscall.

pub fn signal( &self, clear_mask: Signals, set_mask: Signals, ) -> Result<(), Status>

Wraps the zx_object_signal syscall.

pub fn wait_one( &self, signals: Signals, deadline: Instant<MonotonicTimeline>, ) -> WaitResult

Wraps the zx_object_wait_one syscall.

pub fn wait_async( &self, port: &Port, key: u64, signals: Signals, options: WaitAsyncOpts, ) -> Result<(), Status>

Wraps the zx_object_wait_async syscall.

pub fn get_name(&self) -> Result<Name, Status>

Wraps a call to the zx_object_get_property syscall for the ZX_PROP_NAME property.

pub fn set_name(&self, name: &Name) -> Result<(), Status>

Wraps a call to the zx_object_set_property syscall for the ZX_PROP_NAME property.

pub fn basic_info(&self) -> Result<HandleBasicInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_HANDLE_BASIC topic.

pub fn count_info(&self) -> Result<HandleCountInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_HANDLE_COUNT topic.

pub fn koid(&self) -> Result<Koid, Status>

Returns the [Koid] for the object referred to by this handle.

pub fn info(&self) -> Result<BtiInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_BTI topic.

pub fn pin( &self, options: BtiOptions, vmo: &Vmo, offset: u64, size: u64, out_paddrs: &mut [usize], ) -> Result<Pmt, Status>