FakeBtiPinnedVmos

Struct FakeBtiPinnedVmos 

pub struct FakeBtiPinnedVmos { /* private fields */ }
A collection of pinned VMOs returned by FakeBti::get_pinned_vmo.

Implementations

Source

impl FakeBtiPinnedVmos

pub fn find_phys( &self, physical_address: usize, ) -> Option<(Arc<Vmo>, Range<u64>)>

Looks up a physical address in the pinned VMOs.

Returns the VMO and the range of offsets within that VMO starting at the offset corresponding to physical_address and ending at the end of the contiguous pinned block.

pub fn read_bytes(&self, phys_addr: usize, len: usize) -> Result<Vec<u8>, Error>

Reads bytes from physical memory.

The read can span across multiple non-contiguous pinned ranges.

pub fn read<T: FromBytes>(&self, phys_addr: usize) -> Result<T, Error>

Reads T from physical memory.

pub fn write_bytes(&self, phys_addr: usize, data: &[u8]) -> Result<(), Error>

Writes bytes to physical memory.

The write can span across multiple non-contiguous pinned ranges.

pub fn write<T: IntoBytes + Immutable>( &self, phys_addr: usize, value: T, ) -> Result<(), Error>

Writes T to physical memory.